@@ -75,6 +75,7 @@ typedef struct {
   gboolean multi;
   gboolean directory;
   gboolean save;
+  gboolean confirm_overwrite;
   gchar   *separator;
 } ZenityFileData;
 
@@ -82,6 +83,7 @@ typedef struct {
   gchar   *dialog_text;
   gchar   *entry_text;
   gboolean hide_text;
+  const gchar **data;
 } ZenityEntryData;
 
 typedef struct {
@@ -132,6 +134,8 @@ void    zenity_tree             (ZenityData             *data,
                                  ZenityTreeData         *tree_data);
 void	zenity_notification	(ZenityData		*data,
 				 ZenityNotificationData	*notification_data);
+void	zenity_scale		(ZenityData		*data,
+				 ZenityScaleData	*scale_data);
 void    zenity_about            (ZenityData             *data);
 
 G_END_DECLS
